@@ -4,7 +4,7 @@ import copy
 from enum import IntEnum
 from typing import List, Optional, Tuple, Union
 
-from src.pylogos.query_graph.koutrika_query_graph import (Node, Predicate)
+from pylogos.query_graph.koutrika_query_graph import (Node, Predicate)
 
 
 class OperationType(IntEnum):
